summaryrefslogtreecommitdiff
path: root/compiler/GHC/StgToCmm/Expr.hs
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/GHC/StgToCmm/Expr.hs')
-rw-r--r--compiler/GHC/StgToCmm/Expr.hs10
1 files changed, 5 insertions, 5 deletions
diff --git a/compiler/GHC/StgToCmm/Expr.hs b/compiler/GHC/StgToCmm/Expr.hs
index 38d35fc031..f39d02839c 100644
--- a/compiler/GHC/StgToCmm/Expr.hs
+++ b/compiler/GHC/StgToCmm/Expr.hs
@@ -28,7 +28,7 @@ import GHC.StgToCmm.Ticky
import GHC.StgToCmm.Utils
import GHC.StgToCmm.Closure
-import StgSyn
+import GHC.Stg.Syntax
import MkGraph
import BlockId
@@ -42,7 +42,7 @@ import Id
import PrimOp
import TyCon
import Type ( isUnliftedType )
-import RepType ( isVoidTy, countConRepArgs )
+import GHC.Types.RepType ( isVoidTy, countConRepArgs )
import CostCentre ( CostCentreStack, currentCCS )
import Maybes
import Util
@@ -585,7 +585,7 @@ isSimpleOp (StgPrimCallOp _) _ = return False
chooseReturnBndrs :: Id -> AltType -> [CgStgAlt] -> [NonVoid Id]
-- These are the binders of a case that are assigned by the evaluation of the
-- scrutinee.
--- They're non-void, see Note [Post-unarisation invariants] in UnariseStg.
+-- They're non-void, see Note [Post-unarisation invariants] in GHC.Stg.Unarise.
chooseReturnBndrs bndr (PrimAlt _) _alts
= assertNonVoidIds [bndr]
@@ -882,7 +882,7 @@ cgAltRhss gc_plan bndr alts = do
maybeAltHeapCheck gc_plan $
do { _ <- bindConArgs con base_reg (assertNonVoidIds bndrs)
-- alt binders are always non-void,
- -- see Note [Post-unarisation invariants] in UnariseStg
+ -- see Note [Post-unarisation invariants] in GHC.Stg.Unarise
; _ <- cgExpr rhs
; return con }
forkAlts (map cg_alt alts)
@@ -910,7 +910,7 @@ cgConApp con stg_args
do { (idinfo, fcode_init) <- buildDynCon (dataConWorkId con) False
currentCCS con (assertNonVoidStgArgs stg_args)
-- con args are always non-void,
- -- see Note [Post-unarisation invariants] in UnariseStg
+ -- see Note [Post-unarisation invariants] in GHC.Stg.Unarise
-- The first "con" says that the name bound to this
-- closure is "con", which is a bit of a fudge, but
-- it only affects profiling (hence the False)